package com.phm.manage.controller;

import com.phm.common.annotation.Log;
import com.phm.common.core.controller.BaseController;
import com.phm.common.core.domain.AjaxResult;
import com.phm.common.core.page.TableDataInfo;
import com.phm.common.enums.BusinessType;
import com.phm.common.utils.poi.ExcelUtil;
import com.phm.manage.domain.Aircraft;
import com.phm.manage.domain.Fleet;
import com.phm.manage.service.IAircraftService;
import com.phm.manage.service.IFleetService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 单机信息Controller
 *
 * @author phm
 * @date 2023-08-22
 */
@RestController
@RequestMapping("/manage/aircraft")
public class AircraftController extends BaseController {
    @Autowired
    private IAircraftService aircraftService;

    @Autowired
    private IFleetService fleetService;

    /**
     * 查询单机信息列表
     */
    @PreAuthorize("@ss.hasPermi('manage:aircraft:list')")
    @GetMapping("/list")
    public TableDataInfo list(Aircraft aircraft) {
        startPage();
        List<Aircraft> list = aircraftService.selectAircraftList(aircraft);
        return getDataTable(list);
    }

    /**
     * 导出单机信息列表
     */
    @PreAuthorize("@ss.hasPermi('manage:aircraft:export')")
    @Log(title = "单机信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Aircraft aircraft) {
        List<Aircraft> list = aircraftService.selectAircraftList(aircraft);
        ExcelUtil<Aircraft> util = new ExcelUtil<Aircraft>(Aircraft.class);
        util.exportExcel(response, list, "单机信息数据");
    }

    /**
     * 获取单机信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('manage:aircraft:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(aircraftService.selectAircraftById(id));
    }

    /**
     * 新增单机信息
     */
    @PreAuthorize("@ss.hasPermi('manage:aircraft:add')")
    @Log(title = "单机信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Aircraft aircraft) {
        return toAjax(aircraftService.insertAircraft(aircraft));
    }

    /**
     * 修改单机信息
     */
    @PreAuthorize("@ss.hasPermi('manage:aircraft:edit')")
    @Log(title = "单机信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Aircraft aircraft) {
        return toAjax(aircraftService.updateAircraft(aircraft));
    }

    /**
     * 删除单机信息
     */
    @PreAuthorize("@ss.hasPermi('manage:aircraft:remove')")
    @Log(title = "单机信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(aircraftService.deleteAircraftByIds(ids));
    }

    /**
     * 获取机队信息列表
     */
    @PreAuthorize("@ss.hasPermi('manage:aircraft:list')")
    @GetMapping("/fleetList")
    public AjaxResult fleetList(Fleet fleet) {
        return success(fleetService.selectFleetList(fleet));
    }
}
