package com.phm.manage.service.impl;

import com.phm.common.utils.DateUtils;
import com.phm.manage.domain.AnalyzeCourseLog;
import com.phm.manage.mapper.AnalyzeCourseLogMapper;
import com.phm.manage.service.IAnalyzeCourseLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 分析过程日志Service业务层处理
 *
 * @author phm
 * @date 2023-08-31
 */
@Service
public class AnalyzeCourseLogServiceImpl implements IAnalyzeCourseLogService {
    @Autowired
    private AnalyzeCourseLogMapper analyzeCourseLogMapper;

    /**
     * 查询分析过程日志
     *
     * @param id 分析过程日志主键
     * @return 分析过程日志
     */
    @Override
    public AnalyzeCourseLog selectAnalyzeCourseLogById(Long id) {
        return analyzeCourseLogMapper.selectAnalyzeCourseLogById(id);
    }

    /**
     * 查询分析过程日志列表
     *
     * @param analyzeCourseLog 分析过程日志
     * @return 分析过程日志
     */
    @Override
    public List<AnalyzeCourseLog> selectAnalyzeCourseLogList(AnalyzeCourseLog analyzeCourseLog) {
        return analyzeCourseLogMapper.selectAnalyzeCourseLogList(analyzeCourseLog);
    }

    /**
     * 新增分析过程日志
     *
     * @param analyzeCourseLog 分析过程日志
     * @return 结果
     */
    @Override
    public int insertAnalyzeCourseLog(AnalyzeCourseLog analyzeCourseLog) {
        analyzeCourseLog.setCreateTime(DateUtils.getNowDate());
        return analyzeCourseLogMapper.insertAnalyzeCourseLog(analyzeCourseLog);
    }

    /**
     * 修改分析过程日志
     *
     * @param analyzeCourseLog 分析过程日志
     * @return 结果
     */
    @Override
    public int updateAnalyzeCourseLog(AnalyzeCourseLog analyzeCourseLog) {
        analyzeCourseLog.setUpdateTime(DateUtils.getNowDate());
        return analyzeCourseLogMapper.updateAnalyzeCourseLog(analyzeCourseLog);
    }

    /**
     * 批量删除分析过程日志
     *
     * @param ids 需要删除的分析过程日志主键
     * @return 结果
     */
    @Override
    public int deleteAnalyzeCourseLogByIds(Long[] ids) {
        return analyzeCourseLogMapper.deleteAnalyzeCourseLogByIds(ids);
    }

    /**
     * 删除分析过程日志信息
     *
     * @param id 分析过程日志主键
     * @return 结果
     */
    @Override
    public int deleteAnalyzeCourseLogById(Long id) {
        return analyzeCourseLogMapper.deleteAnalyzeCourseLogById(id);
    }
}
