package com.phm.manage.service.impl;

import com.phm.common.utils.DateUtils;
import com.phm.manage.domain.OrderInfo;
import com.phm.manage.mapper.OrderInfoMapper;
import com.phm.manage.service.IOrderInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 系统指令信息Service业务层处理
 *
 * @author phm
 * @date 2023-08-31
 */
@Service
public class OrderInfoServiceImpl implements IOrderInfoService {
    @Autowired
    private OrderInfoMapper orderInfoMapper;

    /**
     * 查询系统指令信息
     *
     * @param id 系统指令信息主键
     * @return 系统指令信息
     */
    @Override
    public OrderInfo selectOrderInfoById(Long id) {
        return orderInfoMapper.selectOrderInfoById(id);
    }

    /**
     * 查询系统指令信息列表
     *
     * @param orderInfo 系统指令信息
     * @return 系统指令信息
     */
    @Override
    public List<OrderInfo> selectOrderInfoList(OrderInfo orderInfo) {
        return orderInfoMapper.selectOrderInfoList(orderInfo);
    }

    /**
     * 新增系统指令信息
     *
     * @param orderInfo 系统指令信息
     * @return 结果
     */
    @Override
    public int insertOrderInfo(OrderInfo orderInfo) {
        orderInfo.initCreatInfo();
        return orderInfoMapper.insertOrderInfo(orderInfo);
    }

    /**
     * 修改系统指令信息
     *
     * @param orderInfo 系统指令信息
     * @return 结果
     */
    @Override
    public int updateOrderInfo(OrderInfo orderInfo) {
        orderInfo.initUpdateInfo();
        return orderInfoMapper.updateOrderInfo(orderInfo);
    }

    /**
     * 批量删除系统指令信息
     *
     * @param ids 需要删除的系统指令信息主键
     * @return 结果
     */
    @Override
    public int deleteOrderInfoByIds(Long[] ids) {
        return orderInfoMapper.deleteOrderInfoByIds(ids);
    }

    /**
     * 删除系统指令信息信息
     *
     * @param id 系统指令信息主键
     * @return 结果
     */
    @Override
    public int deleteOrderInfoById(Long id) {
        return orderInfoMapper.deleteOrderInfoById(id);
    }
}
