package com.phm.manage.service.impl;

import com.phm.common.utils.DateUtils;
import com.phm.manage.domain.Product;
import com.phm.manage.mapper.ProductMapper;
import com.phm.manage.service.IProductService;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 产品树信息Service业务层处理
 *
 * @author phm
 * @date 2023-08-31
 */
@Service
public class ProductServiceImpl implements IProductService {
    @Autowired
    private ProductMapper productMapper;

    /**
     * 查询产品树信息
     *
     * @param id 产品树信息主键
     * @return 产品树信息
     */
    @Override
    public Product selectProductById(Long id) {
        return productMapper.selectProductById(id);
    }

    /**
     * 查询产品树信息列表
     *
     * @param product 产品树信息
     * @return 产品树信息
     */
    @Override
    public List<Product> selectProductList(Product product) {
        return productMapper.selectProductList(product);
    }

    /**
     * 新增产品树信息
     *
     * @param product 产品树信息
     * @return 结果
     */
    @Override
    public int insertProduct(Product product) {
        Product pr = productMapper.selectProductById(product.getParentId());
        if (ObjectUtils.isEmpty(pr)) {
            product.setAncestors(String.valueOf(product.getParentId()));
        } else {
            product.setAncestors(pr.getAncestors() + "," + product.getParentId());
        }
        product.initCreatInfo();
        return productMapper.insertProduct(product);
    }

    /**
     * 修改产品树信息
     *
     * @param product 产品树信息
     * @return 结果
     */
    @Override
    public int updateProduct(Product product) {
        product.initUpdateInfo();
        return productMapper.updateProduct(product);
    }

    /**
     * 批量删除产品树信息
     *
     * @param ids 需要删除的产品树信息主键
     * @return 结果
     */
    @Override
    public int deleteProductByIds(Long[] ids) {
        return productMapper.deleteProductByIds(ids);
    }

    /**
     * 删除产品树信息信息
     *
     * @param id 产品树信息主键
     * @return 结果
     */
    @Override
    public int deleteProductById(Long id) {
        return productMapper.deleteProductById(id);
    }
}
